@@ -85,6 +85,26 @@ def _upload_firmware_stm32f769():
     if subprocess.run(command, **subprocess_run_kwargs).returncode != 0:
         raise RuntimeError("Failed to upload the firmware to the board")
 
+def _upload_firmware_stm32h735():
+    tools_folder = board_tools_folder(Boards.STM32H735G_DK)
+    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
+
+    command = '%s --connect port=SWD ap=0' % programmer_path
+    log.debug(command)
+
+    res = subprocess.Popen(
+        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
+    log.debug(res)
+    if 'stm32h73x' not in res.lower():
+        raise RuntimeError("Failed to connect to the board")
+
+    firmware_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'firmware/stm32h735g-dk-demo.elf')
+    command = '%s --connect port=SWD ap=0 -w %s -hardRst' % (programmer_path, firmware_path)
+    log.debug(command)
+
+    if subprocess.run(command, **subprocess_run_kwargs).returncode != 0:
+        raise RuntimeError("Failed to upload the firmware to the board")
+
 def _upload_firmware_stm32f407():
     tools_folder = board_tools_folder(Boards.STM32F407G_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -174,6 +194,8 @@ def upload_firmware(board):
         _upload_firmware_stm32f769()
     elif board is Boards.STM32H747I_DISCO:
         _upload_firmware_stm32h747()
+    elif board is Boards.STM32H735G_DK:
+            _upload_firmware_stm32h735()
     else:
         raise ValueError("Unsupported board '%s'" % str(board))
 
