@@ -82,6 +82,28 @@ def _upload_param_stm32f469(param_path):
     if res != 0:
         raise RuntimeError("Failed to upload the params to the board")
 
+def _upload_param_stm32h735(param_path):
+    tools_folder = board_tools_folder(Boards.STM32H735G_DK)
+    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
+
+    command = '%s --connect port=SWD ap=0' % programmer_path
+    log.debug(command)
+
+    res = subprocess.Popen(
+        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
+    log.debug(res)
+    if 'stm32h73x' not in res.lower():
+        raise RuntimeError("Failed to connect to the board")
+
+    magic_address = '0x080e0000'
+    command = '%s --connect port=SWD ap=0 -w %s %s -hardRst' % (programmer_path, param_path, magic_address)
+    log.debug(command)
+
+    res = subprocess.run(command, **subprocess_run_kwargs).returncode
+    if res != 0:
+        raise RuntimeError("Failed to upload the params to the board")
+
+
 def _upload_param_stm32f769(param_path):
     tools_folder = board_tools_folder(Boards.STM32F769I_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -186,6 +208,8 @@ def upload_params(ppn_path, rhn_path, board):
             _upload_param_stm32f769(param_path)
         elif board is Boards.STM32H747I_DISCO:
             _upload_param_stm32h747(param_path)
+        elif board is Boards.STM32H735G_DK:
+            _upload_param_stm32h735(param_path)
         else:
             raise ValueError("Unsupported board '%s'" % str(board))
     finally:
